@@ -1,6 +1,9 @@
 // ------------------------------------------------------------------------
 // textdebug.cpp: Implementation of console logging subsystem.
-// Copyright (C) 1999-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// Copyright (C) 1999-2002,2004-2005 Kai Vehmanen
+//
+// Attributes:
+//     eca-style-version: 2
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,8 +26,12 @@
 
 #include <iostream>
 #include <string>
+#include <vector>
+#include <algorithm>
 
 #include <eca-logger-interface.h>
+#include <kvu_utils.h>
+
 #include "textdebug.h"
 
 #ifdef ECA_USE_NCURSES_H
@@ -40,13 +47,52 @@
 
 using namespace std;
 
+/**
+ * Set terminal width used in pretty-printing ecasound console output.
+ *
+ * Value of 79 guarantees that output is readable even in 80x25 terminal mode.
+ */
+const static int tb_terminal_width = 74;
+
+/**
+ * Wraps text 'msg' by adding <newline> + "... " breaks so that none 
+ * of the lines exceed 'width' characteds.
+ */
+static string tb_wrap(const string& msg, int width, int offset)
+{
+  int counter = offset;
+  vector<string> vec = kvu_string_to_vector(msg, ' ');
+  string result;
+  for(vector<string>::const_iterator p = vec.begin(); p != vec.end(); ) {
+    /* check if adding the next token would go over the limit */
+    if ((counter + static_cast<int>(p->size())) > width) {
+      result += "\n... ";
+      counter = 0;
+    }
+    result += *p;
+    /* check if line already contains a newline */
+    if (find(p->begin(), p->end(), '\n') != p->end()) {
+      counter = 0;
+    }
+    else {
+      counter += p->size();
+    }
+    ++p;
+    if (p != vec.end()) {
+      result += " ";
+    }
+  }
+  return result;
+}
+
 void TEXTDEBUG::stream(std::ostream* dos)
 {
   dostream_repp = dos;
 }
 
-std::ostream* TEXTDEBUG::stream(void) { 
-  return(dostream_repp); 
+std::ostream* TEXTDEBUG::stream(void)
+{
+  return dostream_repp;
 }
 
 void TEXTDEBUG::do_flush(void) 
@@ -57,18 +103,25 @@ void TEXTDEBUG::do_flush(void)
 void TEXTDEBUG::do_msg(ECA_LOGGER::Msg_level_t level, const std::string& module_name, const std::string& log_message)
 {
   if (is_log_level_set(level) == true) {
+    int offset = 0;
+
     if (level == ECA_LOGGER::subsystems) {
 #if defined(ECA_USE_NCURSES_H) || defined(ECA_USE_NCURSES_NCURSES_H) || defined(ECA_USE_CURSES_H)
       *dostream_repp << "- [ ";
       putp(tigetstr("bold"));
+      offset += 4;
 #endif
     }
-
-    if (is_log_level_set(ECA_LOGGER::module_names) == true) {
-      *dostream_repp << module_name << ": ";
+    else if (is_log_level_set(ECA_LOGGER::module_names) == true &&
+	     level != ECA_LOGGER::eiam_return_values) {
+      *dostream_repp << "(" 
+		     << std::string(module_name.begin(), 
+				    find(module_name.begin(), module_name.end(), '.'))
+		     << ") ";
+      offset += module_name.size() + 2;
     }
     
-    *dostream_repp << log_message;
+    *dostream_repp << tb_wrap(log_message, tb_terminal_width, offset);
 
     if (level == ECA_LOGGER::subsystems) {
 #if defined(ECA_USE_NCURSES_H) || defined(ECA_USE_NCURSES_NCURSES_H) || defined(ECA_USE_CURSES_H)
@@ -77,8 +130,8 @@ void TEXTDEBUG::do_msg(ECA_LOGGER::Msg_level_t level, const std::string& module_
 #else
       *dostream_repp << " ] ";
 #endif
-      if (log_message.size() < 70) {
-	for (unsigned char n = 0; n < (69 - log_message.size()); n++) *dostream_repp << "-";
+      if (log_message.size() < static_cast<int>(tb_terminal_width)) {
+	for (unsigned char n = 0; n < (tb_terminal_width - log_message.size() - 1); n++) *dostream_repp << "-";
       }
     }
   
