@@ -1,6 +1,9 @@
 // ------------------------------------------------------------------------
 // audiofx_ladspa.cpp: Wrapper class for LADSPA plugins
-// Copyright (C) 2000-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// Copyright (C) 2000-2004 Kai Vehmanen
+//
+// References:
+//     http://www.ladspa.org
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,6 +40,8 @@ EFFECT_LADSPA::EFFECT_LADSPA (const LADSPA_Descriptor *pdesc) throw(ECA_ERROR&)
       LADSPA_PROPERTY_INPLACE_BROKEN)
     throw(ECA_ERROR("AUDIOFX_LADSPA", "Inplace-broken plugins not supported."));
 
+  /* FIXME: strip linefeeds and other forbidden characters; write down to
+   *        to ECA_OBJECT docs what chars are allowed and what are not... */
   name_rep = string(plugin_desc->Name);
   unique_rep = string(plugin_desc->Label);
   maker_rep = string(plugin_desc->Maker);
@@ -52,8 +57,10 @@ EFFECT_LADSPA::~EFFECT_LADSPA (void)
   
   if (plugin_desc != 0) {
     for(unsigned int n = 0; n < plugins_rep.size(); n++) {
-      if (plugin_desc->deactivate != 0) plugin_desc->deactivate(plugins_rep[n]);
-      plugin_desc->cleanup(plugins_rep[n]);
+      if (plugin_desc->deactivate != 0) 
+	plugin_desc->deactivate(plugins_rep[n]);
+      if (plugin_desc->cleanup != 0)
+	plugin_desc->cleanup(plugins_rep[n]);
     }
   }
 }
@@ -94,9 +101,8 @@ void EFFECT_LADSPA::init_ports(void)
       params.push_back(pd.default_value);
       param_descs_rep.push_back(pd);
       if (params.size() > 1) param_names_rep += ",";
-      string temp = kvu_string_search_and_replace(string(plugin_desc->PortNames[m]), ',', ' ');
-      temp = kvu_string_search_and_replace(temp, ':', ' ');
-      param_names_rep += temp;
+      string tmp (kvu_string_search_and_replace(string(plugin_desc->PortNames[m]), ",", "\\,"));
+      param_names_rep += kvu_string_search_and_replace(tmp, ":", "\\:");
     }
   }
 }
