@@ -1,7 +1,6 @@
 // ------------------------------------------------------------------------
 // audiofx_rcfilter.cpp: Simulation of an 3rd-order 36dB active RC-lowpass
-// Copyright (C) 2000 Stefan Fendt <stefan@lionfish.ping.de>,
-//                    Kai Vehmanen <kaiv@wakkanet.fi> (C++ version)
+// Copyright (C) 2000 Stefan Fendt, Kai Vehmanen (C++ version)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,19 +18,19 @@
 // ------------------------------------------------------------------------
 
 #include <cmath>
-#include <kvutils.h>
+#include <kvu_utils.h>
 
 #include "samplebuffer_iterators.h"
-#include "eca-debug.h"
+#include "eca-logger.h"
 #include "audiofx_rcfilter.h"
 
-EFFECT_RC_LOWPASS_FILTER::EFFECT_RC_LOWPASS_FILTER (CHAIN_OPERATOR::parameter_type cutoff, 
-						    CHAIN_OPERATOR::parameter_type resonance) {
+EFFECT_RC_LOWPASS_FILTER::EFFECT_RC_LOWPASS_FILTER (CHAIN_OPERATOR::parameter_t cutoff, 
+						    CHAIN_OPERATOR::parameter_t resonance) {
   set_parameter(1, cutoff);
   set_parameter(2, resonance);
 }
 
-void EFFECT_RC_LOWPASS_FILTER::set_parameter(int param, CHAIN_OPERATOR::parameter_type value) {
+void EFFECT_RC_LOWPASS_FILTER::set_parameter(int param, CHAIN_OPERATOR::parameter_t value) {
   switch (param) {
   case 1: 
     cutoff_rep = value;
@@ -42,7 +41,7 @@ void EFFECT_RC_LOWPASS_FILTER::set_parameter(int param, CHAIN_OPERATOR::paramete
   }
 }
 
-CHAIN_OPERATOR::parameter_type EFFECT_RC_LOWPASS_FILTER::get_parameter(int param) const { 
+CHAIN_OPERATOR::parameter_t EFFECT_RC_LOWPASS_FILTER::get_parameter(int param) const { 
   switch (param) {
   case 1: 
     return(cutoff_rep);
