@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // audioio-cdr.cpp: CDDA/CDR audio file format input/output
-// Copyright (C) 1999,2001 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// Copyright (C) 1999,2001 Kai Vehmanen
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -155,7 +155,7 @@ void CDRFILE::seek_position(void) {
     }
 #else
     DBC_CHECK(sizeof(long int) == sizeof(off_t));
-    std::fseek(fobject, curpos_rep, SEEK_SET);
+    std::fseek(fobject, static_cast<long int>(curpos_rep), SEEK_SET);
 #endif
   }
 }
