@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
-// audioio-ogg.cpp: Interface for ogg vorbis ecoders and encoders.
-// Copyright (C) 2000-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// audioio-ogg.cpp: Interface for ogg vorbis decoders and encoders.
+// Copyright (C) 2000-2002,2004-2005 Kai Vehmanen
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,18 +29,18 @@
 
 #include "eca-logger.h"
 
-string OGG_VORBIS_INTERFACE::default_ogg_input_cmd = "ogg123 -d raw --file=- %f";
-string OGG_VORBIS_INTERFACE::default_ogg_output_cmd = "oggenc -b 128 --raw --raw-bits=%b --raw-chan=%c --raw-rate=%s --output=%f -";
-long int OGG_VORBIS_INTERFACE::default_ogg_output_default_bitrate = 128000;
+string OGG_VORBIS_INTERFACE::default_input_cmd = "ogg123 -d raw -o byteorder:%E --file=- %f";
+string OGG_VORBIS_INTERFACE::default_output_cmd = "oggenc -b %B --raw --raw-bits=%b --raw-chan=%c --raw-rate=%s --raw-endianness 0 --output=%f -";
+long int OGG_VORBIS_INTERFACE::default_output_default_bitrate = 128000;
 
-void OGG_VORBIS_INTERFACE::set_ogg_input_cmd(const std::string& value) { OGG_VORBIS_INTERFACE::default_ogg_input_cmd = value; }
-void OGG_VORBIS_INTERFACE::set_ogg_output_cmd(const std::string& value) { OGG_VORBIS_INTERFACE::default_ogg_output_cmd = value; }
+void OGG_VORBIS_INTERFACE::set_input_cmd(const std::string& value) { OGG_VORBIS_INTERFACE::default_input_cmd = value; }
+void OGG_VORBIS_INTERFACE::set_output_cmd(const std::string& value) { OGG_VORBIS_INTERFACE::default_output_cmd = value; }
 
 OGG_VORBIS_INTERFACE::OGG_VORBIS_INTERFACE(const std::string& name)
 {
   set_label(name);
   finished_rep = false;
-  bitrate_rep = OGG_VORBIS_INTERFACE::default_ogg_output_default_bitrate;
+  bitrate_rep = OGG_VORBIS_INTERFACE::default_output_default_bitrate;
 }
 
 OGG_VORBIS_INTERFACE::~OGG_VORBIS_INTERFACE(void)
@@ -55,11 +55,6 @@ void OGG_VORBIS_INTERFACE::open(void) throw (AUDIO_IO::SETUP_ERROR &)
   std::string urlprefix;
   triggered_rep = false;
 
-  /**
-   * FIXME: we have no idea about the audio format of the 
-   *        stream we get from ogg123!
-   */
-
   if (io_mode() == io_read) {
     struct stat buf;
     int ret = ::stat(label().c_str(), &buf);
@@ -73,6 +68,18 @@ void OGG_VORBIS_INTERFACE::open(void) throw (AUDIO_IO::SETUP_ERROR &)
 	ECA_LOG_MSG(ECA_LOGGER::user_objects, "(audioio-ogg) Found url; protocol '" + urlprefix + "'.");
       }
     }
+
+    /* decoder supports: nothing configurable nor fixed
+     * 
+     * FIXME: we have no idea about the audio format of the 
+     *        stream we get from the decoder... ybe we should force the decoder
+     *        to generate RIFF wave to a named pipe and parse the header...? 
+     */
+  }
+  else {
+    /* encoder supports: coding, channel-count and srate configurable,
+     *                   fixed to little endian */
+    ECA_AUDIO_FORMAT::set_sample_endianess(ECA_AUDIO_FORMAT::se_little);
   }
 
   AUDIO_IO::open();
@@ -93,7 +100,7 @@ long int OGG_VORBIS_INTERFACE::read_samples(void* target_buffer, long int sample
 {
   if (triggered_rep != true) { 
     triggered_rep = true;
-    fork_ogg_input();
+    fork_input_process();
   }
 
   if (f1_rep != 0) {
@@ -105,7 +112,7 @@ long int OGG_VORBIS_INTERFACE::read_samples(void* target_buffer, long int sample
 
   if (bytes_rep < samples * frame_size() || bytes_rep == 0) {
     if (position_in_samples() == 0) 
-      ECA_LOG_MSG(ECA_LOGGER::info, "(audioio-ogg) Can't start process \"" + OGG_VORBIS_INTERFACE::default_ogg_input_cmd + "\". Please check your ~/.ecasoundrc.");
+      ECA_LOG_MSG(ECA_LOGGER::info, "(audioio-ogg) Can't start process \"" + fork_command() + "\". Please check your ~/.ecasound/ecasoundrc.");
     finished_rep = true;
     triggered_rep = false;
   }
@@ -119,7 +126,7 @@ void OGG_VORBIS_INTERFACE::write_samples(void* target_buffer, long int samples)
 {
   if (triggered_rep != true) {
     triggered_rep = true;
-    fork_ogg_output();
+    fork_output_process();
   }
 
   if (wait_for_child() != true) {
@@ -127,8 +134,8 @@ void OGG_VORBIS_INTERFACE::write_samples(void* target_buffer, long int samples)
     triggered_rep = false;
   }
   else {
-    if (fd_rep > 0) {
-      bytes_rep = ::write(fd_rep, target_buffer, frame_size() * samples);
+    if (filedes_rep > 0) {
+      bytes_rep = ::write(filedes_rep, target_buffer, frame_size() * samples);
     }
     else {
       bytes_rep = 0;
@@ -162,7 +169,7 @@ void OGG_VORBIS_INTERFACE::set_parameter(int param, string value)
     if (numvalue > 0) 
       bitrate_rep = numvalue;
     else
-      bitrate_rep = OGG_VORBIS_INTERFACE::default_ogg_output_default_bitrate;
+      bitrate_rep = OGG_VORBIS_INTERFACE::default_output_default_bitrate;
     break;
   }
 }
@@ -179,16 +186,26 @@ string OGG_VORBIS_INTERFACE::get_parameter(int param) const
   return("");
 }
 
-void OGG_VORBIS_INTERFACE::fork_ogg_input(void)
+void OGG_VORBIS_INTERFACE::fork_input_process(void)
 {
-  ECA_LOG_MSG(ECA_LOGGER::user_objects, OGG_VORBIS_INTERFACE::default_ogg_input_cmd);
-  set_fork_command(OGG_VORBIS_INTERFACE::default_ogg_input_cmd);
+  string command = OGG_VORBIS_INTERFACE::default_input_cmd;
+
+  // replace with 'little/big' byteorder
+  if (command.find("%E") != string::npos) {
+    string byteorder ("big");
+    if (sample_endianess() == ECA_AUDIO_FORMAT::se_little) byteorder = "little";
+    command.replace(command.find("%E"), 2, byteorder);
+  }
+
+  set_fork_command(command);
   set_fork_file_name(label());
   set_fork_pipe_name();
   fork_child_for_read();
   if (child_fork_succeeded() == true) {
-    fd_rep = file_descriptor();
-    f1_rep = fdopen(fd_rep, "r"); /* not part of <cstdio> */
+    /* NOTE: the file description will be closed by 
+     *       AUDIO_IO_FORKED_STREAM::clean_child() */
+    filedes_rep = file_descriptor();
+    f1_rep = fdopen(filedes_rep, "r"); /* not part of <cstdio> */
     if (f1_rep == 0) {
       finished_rep = true;
       triggered_rep = false;
@@ -198,18 +215,17 @@ void OGG_VORBIS_INTERFACE::fork_ogg_input(void)
     f1_rep = 0;
 }
 
-void OGG_VORBIS_INTERFACE::fork_ogg_output(void)
+void OGG_VORBIS_INTERFACE::fork_output_process(void)
 {
   ECA_LOG_MSG(ECA_LOGGER::info, "(audioio-ogg) Starting to encode " + label() + " with vorbize.");
-  string command_rep = OGG_VORBIS_INTERFACE::default_ogg_output_cmd;
-  if (command_rep.find("%f") != string::npos) {
-    command_rep.replace(command_rep.find("%f"), 2, label());
-  }
-  if (command_rep.find("%B") != string::npos) {
-    command_rep.replace(command_rep.find("%B"), 2, kvu_numtostr((long int)(bitrate_rep / 1000)));
+  string command = OGG_VORBIS_INTERFACE::default_output_cmd;
+
+  // replace with bitrate
+  if (command.find("%B") != string::npos) {
+    command.replace(command.find("%B"), 2, kvu_numtostr((long int)(bitrate_rep / 1000)));
   }
 
-  set_fork_command(command_rep);
+  set_fork_command(command);
   set_fork_file_name(label());
 
   set_fork_bits(bits());
@@ -218,9 +234,9 @@ void OGG_VORBIS_INTERFACE::fork_ogg_output(void)
 
   fork_child_for_write();
   if (child_fork_succeeded() == true) {
-    fd_rep = file_descriptor();
+    filedes_rep = file_descriptor();
   }
   else {
-    fd_rep = 0;
+    filedes_rep = 0;
   }
 }
