@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------
 // eca-chainsetup-parser.cpp: Functionality for parsing chainsetup 
 //                            option syntax.
-// Copyright (C) 2001-2005 Kai Vehmanen
+// Copyright (C) 2001-2006 Kai Vehmanen
 //
 // Attributes:
 //     eca-style-version: 3
@@ -346,13 +346,13 @@ void ECA_CHAINSETUP_PARSER::interpret_general_option (const string& argu)
     {
       int prio = ::atoi(kvu_get_argument_number(1, argu).c_str());
       if (prio < 0) {
-	ECA_LOG_MSG(ECA_LOGGER::info, "(eca-chainsetup) Raised-priority mode disabled.");
+	ECA_LOG_MSG(ECA_LOGGER::info, "Raised-priority mode disabled.");
 	csetup_repp->toggle_raised_priority(false);
       }
       else {
 	if (prio == 0) prio = 50;
 	csetup_repp->set_sched_priority(prio);
-	ECA_LOG_MSG(ECA_LOGGER::info, "(eca-chainsetup) Raised-priority mode enabled. (prio:" + 
+	ECA_LOG_MSG(ECA_LOGGER::info, "Raised-priority mode enabled. (prio:" + 
 		      kvu_numtostr(prio) + ")");
 	csetup_repp->toggle_raised_priority(true);
       }
@@ -619,12 +619,17 @@ void ECA_CHAINSETUP_PARSER::interpret_effect_preset (const string& argu)
       ECA_LOG_MSG(ECA_LOGGER::system_objects, "Interpreting preset \"" + argu + "\".");
       CHAIN_OPERATOR* cop = 0;
 
+      if (csetup_repp->selected_chainids.size() != 1) {
+	ECA_LOG_MSG(ECA_LOGGER::info, 
+		    "ERROR: Exactly one chain should be selected when adding chain operators.");
+	match = false;
+      }
+
       if (argu.size() < 3) return;  
       switch(argu[2]) {
       case 'f':
 	{
 #ifndef ECA_DISABLE_EFFECTS
-//  	  add_chain_operator(dynamic_cast<CHAIN_OPERATOR*>(new FILE_PRESET(kvu_get_argument_number(1,argu))));
           cop = dynamic_cast<CHAIN_OPERATOR*>(new FILE_PRESET(kvu_get_argument_number(1,argu)));
 #endif
 	  break;
@@ -649,7 +654,7 @@ void ECA_CHAINSETUP_PARSER::interpret_effect_preset (const string& argu)
           for(int n = 0; n < cop->number_of_params(); n++) {
               cop->set_parameter(n + 1, atof(kvu_get_argument_number(n + 2, argu).c_str()));
           }
-          csetup_repp->add_chain_operator(cop);
+	  csetup_repp->add_chain_operator(cop);
       }
       break;
     }
@@ -951,8 +956,15 @@ void ECA_CHAINSETUP_PARSER::interpret_chain_operator (const string& argu)
   CHAIN_OPERATOR* t = ECA_OBJECT_FACTORY::create_chain_operator(argu);
   if (t == 0) t = ECA_OBJECT_FACTORY::create_ladspa_plugin(argu);
   if (t != 0) {
-    csetup_repp->add_chain_operator(t);
-    istatus_rep = true;
+    if (csetup_repp->selected_chainids.size() == 1) {
+      csetup_repp->add_chain_operator(t);
+      istatus_rep = true;
+    }
+    else {
+      ECA_LOG_MSG(ECA_LOGGER::info, 
+		  "ERROR: Exactly one chain should be selected when adding chain operators.");
+      delete t;
+    }
   }
   else 
     interpret_effect_preset(argu);
@@ -982,13 +994,20 @@ void ECA_CHAINSETUP_PARSER::interpret_controller (const string& argu)
   else {
     GENERIC_CONTROLLER* t = ECA_OBJECT_FACTORY::create_controller(argu);
     if (t != 0) {
-      MIDI_CLIENT* p = dynamic_cast<MIDI_CLIENT*>(t->source_pointer());
-      if (p != 0) {
-	csetup_repp->midi_server_needed_rep = true;
-	p->register_server(csetup_repp->midi_server_repp);
+      if (csetup_repp->selected_chainids.size() != 1) {
+	ECA_LOG_MSG(ECA_LOGGER::info, 
+		    "ERROR: Exactly one chain should be selected when adding controllers.");
+	delete t;
+      }
+      else {
+	MIDI_CLIENT* p = dynamic_cast<MIDI_CLIENT*>(t->source_pointer());
+	if (p != 0) {
+	  csetup_repp->midi_server_needed_rep = true;
+	  p->register_server(csetup_repp->midi_server_repp);
+	}
+	csetup_repp->add_controller(t);
+	istatus_rep = true;
       }
-      csetup_repp->add_controller(t);
-      istatus_rep = true;
     }
   }
 }
@@ -1122,8 +1141,10 @@ string ECA_CHAINSETUP_PARSER::inputs_to_string(void) const
       ++cp;
       if (cp != c.end()) t << ",";
     }
-    t << " ";
-    t << audioio_to_string(csetup_repp->inputs[p], "i");
+    t << " " 
+      << ECA_OBJECT_FACTORY::audio_object_format_to_eos(csetup_repp->inputs[p]) 
+      << " "
+      << ECA_OBJECT_FACTORY::audio_object_to_eos(csetup_repp->inputs[p]);
 
     if (csetup_repp->input_start_pos[p] != 0) {
       t << " -y:" << csetup_repp->input_start_pos[p];
@@ -1151,8 +1172,10 @@ string ECA_CHAINSETUP_PARSER::outputs_to_string(void) const
       ++cp;
       if (cp != c.end()) t << ",";
     }
-    t << " ";
-    t << audioio_to_string(csetup_repp->outputs[p], "o");
+    t << " " 
+      << ECA_OBJECT_FACTORY::audio_object_format_to_eos(csetup_repp->outputs[p]) 
+      << " "
+      << ECA_OBJECT_FACTORY::audio_object_to_eos(csetup_repp->outputs[p]);
 
     if (csetup_repp->output_start_pos[p] != 0) {
       t << " -y:" << csetup_repp->output_start_pos[p];
@@ -1184,18 +1207,3 @@ string ECA_CHAINSETUP_PARSER::chains_to_string(void) const
   return t.to_string();
 }
 
-string ECA_CHAINSETUP_PARSER::audioio_to_string(const AUDIO_IO* aiod, const string& direction) const
-{
-  MESSAGE_ITEM t;
-
-  t << "-f:" << aiod->format_string() << "," <<
-    aiod->channels() << ","  << aiod->samples_per_second();
-  t << " -" << direction << ":";
-  for(int n = 0; n < aiod->number_of_params(); n++) {
-    // FIXME: should quote/escape possible commas and whitespace
-    t << aiod->get_parameter(n + 1);
-    if (n + 1 < aiod->number_of_params()) t << ",";
-  }
-
-  return t.to_string();
-}
