@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // eca-chainsetup.cpp: Class representing an ecasound chainsetup object.
-// Copyright (C) 1999-2005 Kai Vehmanen
+// Copyright (C) 1999-2006 Kai Vehmanen
 // Copyright (C) 2005 Stuart Allie
 //
 // Attributes:
@@ -1161,7 +1161,8 @@ int ECA_CHAINSETUP::number_of_non_realtime_outputs(void) const
 AUDIO_IO_MANAGER* ECA_CHAINSETUP::get_audio_object_manager(AUDIO_IO* aio) const
 {
   for(vector<AUDIO_IO_MANAGER*>::const_iterator q = aio_managers_rep.begin(); q != aio_managers_rep.end(); q++) {
-    if ((*q)->get_object_id(aio) != -1) {
+    if ((*q)->is_managed_type(aio) && 
+	(*q)->get_object_id(aio) != -1) {
       ECA_LOG_MSG(ECA_LOGGER::system_objects, 
 		    "Found object manager '" +
 		    (*q)->name() + 
@@ -1914,7 +1915,7 @@ void ECA_CHAINSETUP::calculate_processing_length(void)
 	max_input_length > 0) {
       /* looping but length not set */
       ECA_LOG_MSG(ECA_LOGGER::info, 
-		  "(eca-chainsetup-parser) Setting loop point to "
+		  "Setting loop point to "
 		   + kvu_numtostr(length_in_seconds_exact()) + ".");
       set_max_length_in_samples(max_input_length);
     }
@@ -2013,22 +2014,18 @@ void ECA_CHAINSETUP::set_samples_per_second(SAMPLE_SPECS::sample_rate_t new_valu
 
 /**
  * Reimplemented from ECA_AUDIO_POSITION.
- *
- * @pre is_enabled() == true
  */
 void ECA_CHAINSETUP::seek_position(void)
 {
-  // --------
-  DBC_REQUIRE(is_enabled() == true);
-  // --------
-
   ECA_LOG_MSG(ECA_LOGGER::user_objects,
 		"seek position, chainsetup '" +
 		name() +
 		"' to pos in sec " + 
 		kvu_numtostr(position_in_seconds()) + ".");
 
-  if (double_buffering() == true) pserver_repp->flush();
+  if (is_enabled() == true) {
+    if (double_buffering() == true) pserver_repp->flush();
+  }
 
   for(vector<AUDIO_IO*>::iterator q = inputs.begin(); q != inputs.end(); q++) {
     (*q)->seek_position_in_samples(position_in_samples());
@@ -2240,6 +2237,7 @@ void ECA_CHAINSETUP::add_controller(GENERIC_CONTROLLER* csrc)
   // --------
   DBC_REQUIRE(csrc != 0);
   DBC_REQUIRE(is_locked() != true);
+  DBC_REQUIRE(selected_chains().size() == 1);
   // --------
 
 #ifndef ECA_DISABLE_EFFECTS
@@ -2276,6 +2274,7 @@ void ECA_CHAINSETUP::add_chain_operator(CHAIN_OPERATOR* cotmp)
   // --------
   DBC_REQUIRE(cotmp != 0);
   DBC_REQUIRE(is_locked() != true);
+  DBC_REQUIRE(selected_chains().size() == 1);
   // --------
   
 #ifndef ECA_DISABLE_EFFECTS
