@@ -28,7 +28,7 @@ class ECA_ENGINE_impl {
   double looptimer_mid_rep;
   double looptimer_high_rep;
 
-  VALUE_QUEUE command_queue_rep;
+  VALUE_QUEUE_RT_C command_queue_rep;
 
   pthread_cond_t ecasound_stop_cond_repp;
   pthread_mutex_t ecasound_stop_mutex_repp;
