@@ -1,6 +1,9 @@
 // ------------------------------------------------------------------------
-// eca_resources.cpp: User settings (~/.ecasoundrc)
-// Copyright (C) 1999-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// eca_resources.cpp: User settings (ecasoundrc)
+// Copyright (C) 1999-2002,2004,2005 Kai Vehmanen
+//
+// Attributes:
+//     eca-style-version: 3
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -36,14 +39,13 @@ using std::string;
 ECA_RESOURCES::ECA_RESOURCES(void) 
   : resources_found_rep(true)
 {
-  string ecasound_prefix (ECA_PREFIX);
-  string ecasound_resource_path = ecasound_prefix + "/share/ecasound";
+  string ecasound_resource_path (ECA_PKGDATADIR);
 
   globalrc_repp = new RESOURCE_FILE();
   globalrc_repp->resource_file(ecasound_resource_path + "/ecasoundrc");
   globalrc_repp->load();
   if (globalrc_repp->keywords().size() == 0) {
-    ECA_LOG_MSG(ECA_LOGGER::info, "(eca-resources) Warning! Global resource file '" + ecasound_resource_path + "/ecasoundrc" + "' not available! Ecasound may not function properly!");
+    ECA_LOG_MSG(ECA_LOGGER::info, "WARNING: Global resource file '" + ecasound_resource_path + "/ecasoundrc" + "' not available! Ecasound may not function properly!");
     resources_found_rep = false;
   }
 
@@ -57,7 +59,7 @@ ECA_RESOURCES::ECA_RESOURCES(void)
     userrc_repp->resource_file(user_ecasoundrc_path + "/ecasoundrc");
     userrc_repp->load();
     if (userrc_repp->has("user-resource-directory") == true) {
-      ECA_LOG_MSG(ECA_LOGGER::info, "(eca-resources) Warning! Old resource data found in '" + user_ecasoundrc_path + ". You can reset configuration parameters by removing the old rc-file.");
+      ECA_LOG_MSG(ECA_LOGGER::info, "WARNING: Old resource data found in '" + user_ecasoundrc_path + ". You can reset configuration parameters by removing the old rc-file.");
     }
   }
 }
@@ -94,15 +96,15 @@ void ECA_RESOURCES::resource(const string& tag, const string& value)
 string ECA_RESOURCES::resource(const string& tag) const
 {
   if (tag == "user-resource-directory") 
-    return(user_resource_directory_rep);
+    return user_resource_directory_rep;
   
   if (userrc_repp->has(tag))
-    return(userrc_repp->resource(tag));
+    return userrc_repp->resource(tag);
   
   if (globalrc_repp->has(tag))
-    return(globalrc_repp->resource(tag));
+    return globalrc_repp->resource(tag);
 
-  return("");
+  return "";
 }
 
 /**
@@ -111,13 +113,13 @@ string ECA_RESOURCES::resource(const string& tag) const
 bool ECA_RESOURCES::boolean_resource(const string& tag) const
 {
   if (userrc_repp->has(tag)) {
-    return(userrc_repp->boolean_resource(tag));
+    return userrc_repp->boolean_resource(tag);
   }
   else if (globalrc_repp->has(tag)) {
-    return(globalrc_repp->boolean_resource(tag));
+    return globalrc_repp->boolean_resource(tag);
   }
 
-  return(false);
+  return false;
 }
   
 /**
@@ -125,8 +127,8 @@ bool ECA_RESOURCES::boolean_resource(const string& tag) const
  */
 bool ECA_RESOURCES::has(const string& tag) const
 {
-  if (globalrc_repp->has(tag) || userrc_repp->has(tag)) return(true);
-  return(false);
+  if (globalrc_repp->has(tag) || userrc_repp->has(tag)) return true;
+  return false;
 }
 
 /**
@@ -134,5 +136,5 @@ bool ECA_RESOURCES::has(const string& tag) const
  */
 bool ECA_RESOURCES::has_any(void) const
 {
-  return(resources_found_rep);
+  return resources_found_rep;
 }
